@@ -1,7 +1,6 @@
 from abc import ABC, abstractmethod
 from uuid import UUID
 from typing import Type, Any, List, Union, Dict
-from functools import wraps
 from warnings import warn
 from pandas import DataFrame
 import pandas
@@ -9,9 +8,9 @@ from pydantic import BaseModel, Field
 import weakref
 
 from metagen.base import LeafABC
-from metagen.config import config
 
 # TODO: Solve weak references
+# TODO: Element look up for pandas
 
 
 class Register(BaseModel, ABC):
@@ -24,6 +23,10 @@ class Register(BaseModel, ABC):
     def add(self, element: Type[LeafABC]) -> None:
         pass
 
+    @abstractmethod
+    def update(self, attrName: str, value: Any)-> None:
+        pass
+
     @abstractmethod
     def check_register(self, element: Type[LeafABC]) -> bool:
         pass
@@ -62,6 +65,9 @@ class DictRegister(Register):
             raise ValueError(f'PTR element "{element.__class__.__name__}" with nameInternal: {element.nameInternal}, '
                              f'key: {element.key} and hash: {hash(element)} already exist')
 
+    def update(self, attrName: str, value: Any)-> None:
+        raise NotImplementedError()
+
     def check_register(self, element: Type[LeafABC]) -> bool:
         return all([self.hashs.get(hash(element)), self.name.get(element.nameInternal)])
 
@@ -98,6 +104,9 @@ class PandasRegister(Register):
         element_pd = DataFrame(prepare_element4pandas(element), index=['key'])
         self.table = pandas.concat([self.table, element_pd], ignore_index=True, axis=0)
 
+    def update(self, attrName: str, value: Any):
+        raise NotImplementedError()
+
     def check_register(self, element: Type[LeafABC])-> bool:
             if self.get_by_hash(hash(element)):
                 return True
@@ -132,27 +141,10 @@ class RegisterFactory(BaseModel):
     def add(self, registerName: str, registerType: Type[Register]) -> None:
         self.registers.update({registerName: registerType})
 
-    def get(self, registerName: str) -> Type[Register]:
+    def get(self, registerName: str, **ignore) -> Type[Register]:
         return self.registers[registerName]
 
 
 register_factory = RegisterFactory()
 register_factory.add(registerName='dict', registerType=DictRegister)
 register_factory.add(registerName='pandas', registerType=PandasRegister)
-register = register_factory.get(registerName=config.registerName)()
-
-
-def exist_in_register(element):
-    @wraps(element)
-    def checking_register(*args, **kwargs):
-        instance = element(*args, **kwargs)
-        if register.check_register(instance):
-            registered_element = register.get_by_hash(hash(instance))
-            warn(f'Element duplication: Element {instance.__class__.__name__} with parameters: '
-                 f'{"; ".join([f"{k}: {v}" for k, v in kwargs.items()])} found in register. Element '
-                 f'{registered_element.__repr__()} returned instead')
-            return registered_element
-        else:
-            register.add(instance)
-            return instance
-    return checking_register
